
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class LearningObjectBuilder
  def self.build_from_dspace(item)
    lo = LearningObject.new(
      name: item.name,
      id_dspace: item.id,
      thumbnail: nil,
      metadata: dspace_metadata_to_hash(item.metadata)
    )

    lo.curator = lo.get_metadata_value_of('dc.curator')
    institution = lo.get_metadata_value_of('dc.creator')
    institution = 'Desconhecido' if institution.blank?
    lo.publisher = Institution.where(name: institution).first_or_create

    object_type = lo.get_metadata_value_of('dc.type')
    object_type = 'Desconhecido' if object_type.blank?
    lo.object_type = ObjectType.where(name: object_type).first_or_create

    date = lo.get_metadata_value_of('dc.date.issued')
    lo.published_at = Time.iso8601(date) unless date.nil?

    code = lo.get_metadata_value_of('dc.language')
    code = 'pt' if code.blank?
    language = Language.where(code: code).first
    language = Language.create(name: code, code: code) if language.nil?
    lo.language = language

    lo.author = lo.get_metadata_values_of('dc.contributor.author').join(', ')
    lo.description = lo.get_metadata_value_of('dc.description')

    lo.state = LearningObject.states[:published]

    lo
  end

  def self.dspace_metadata_to_hash(metadata)
    hash = Hash.new { |h, k| h[k] = Array.new(&h.default_proc) }
    metadata.each { |m| hash[m.key] << m.value }
    hash
  end
end
