
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.
module SubmissionController
    extend ActiveSupport::Concern
    include ::Paginator

    included do
        before_action :set_new_submission, only: :submit
        before_action :set_submission, only: :show_submission
        before_action :authorize!
    end

    def submissions
        learning_objects = paginate LearningObject.where(state: LearningObject.states[:submitted])
        render json: learning_objects
    end

    def submit
        return render status: :ok if @learning_object.submitted?

        if @learning_object.update(state: LearningObject.states[:submitted])
            render json: @learning_object, status: :ok
        else
            render json: @learning_object.errors, status: :unprocessable_entity
        end
    end

    def show_submission
      return render status: :ok if @learning_object.draft? || @learning_object.published?
      render json: @learning_object
    end

    private

    def submitted
        return @learning_object.submitted?
    end

    def set_new_submission
        @learning_object = LearningObject.find(params[:id])
    end

    def set_submission
      @learning_object ||= LearningObject.find(params[:id])
    end

end
