
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class V1::Users::BookmarksController < ApplicationController
  before_action :authenticate_user!
  before_action :set_user
  before_action :authorize!
  before_action :find_object, only: [:create, :destroy]

  # GET /v1/users/:user_id/bookmarks
  # GET /v1/users/:user_id/bookmarks.json
  def index
    render json: @user.bookmarks, status: :ok
  end

  # POST /v1/users/:user_id/bookmarks
  # POST /v1/users/:user_id/bookmarks.json
  def create
    bookmark = Bookmark.new(user: @user, bookmarkable: @object)
    if bookmark.save
      render json: bookmark, status: :created
    else
      render json: bookmark.errors, status: :unprocessable_entity
    end
  end

  def destroy
    Bookmark.where(user: @user, bookmarkable: @object).destroy_all
    render status: :ok
  end

  private

  def authorize!
    authorize Bookmark.new(user: @user)
  end

  def set_user
    @user = User.find(params[:user_id])
  end

  def find_object
    if %w(LearningObject Collection).include? bookmarks_params[:type]
      klass = bookmarks_params[:type].constantize
      @object = klass.find bookmarks_params[:id]
    else
      return render status: :not_acceptable
    end
  end

  def bookmarks_params
    params.require(:bookmarks).permit(:id, :type)
  end

end
