
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

module Tagger
  extend ActiveSupport::Concern

  included do
    has_many :taggings, as: :tagger, dependent: :destroy
  end

  # An tagger can tagging learning object and collection
  # Examples:
  # tagger.tag(LearningObject.find(1), with: "Tag")
  # tagger.tag(Collection.find(1), with: "Tag")
  def tag(taggable, with: [])
    with.each do |tag_name|
      tag = Tag.where(name: tag_name).first_or_create
      Tagging.where(tag: tag, tagger_id: id, tagger_type: self.class.name, taggable_id: taggable, taggable_type: taggable.class.name).first_or_create
    end
  end

  # An tagger can untagging learning object and collection
  # Examples:
  # tagger.untag(LearningObject.find(1), "Tag")
  # tagger.untag(Collection.find(1), "Tag")
  def untag(taggable, with: [])
    with.each do |tag_name|
      tag = Tag.find_by(name: tag_name)
      Tagging.where(tagger: self, tag: tag, taggable: taggable).destroy_all
    end
  end
end
