
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

# == Schema Information
#
# Table name: learning_object_attachments
#
#  id                     :integer          not null, primary key
#  name                   :string
#  link                   :string
#  retrieve_link          :string
#  description            :text
#  format                 :string
#  mime_type              :string
#  size                   :integer
#  bundle_name            :string
#  learning_object_id     :integer
#  created_at             :datetime         not null
#  updated_at             :datetime         not null
#  id_dspace              :integer
#  thumbnail_file_name    :string
#  thumbnail_content_type :string
#  thumbnail_file_size    :integer
#  thumbnail_updated_at   :datetime
#  cache_link             :string
#

class LearningObject::Attachment < ApplicationRecord
  include ::Thumbnailable
  belongs_to :learning_object
  scope :unknown_mime_type, ->() { where(format: 'Unknown') }
  has_one :attachment, class_name: 'LearningObject::Attachment'
  belongs_to :attachment, class_name: 'LearningObject::Attachment'
  # has_and_belongs_to_many
  # belongs_to

  def retrieve_url
    "#{DspaceService.link}/rest#{retrieve_link}"
  end

  def retrieve_cache_link
    return retrieve_url unless bundle_name == 'ORIGINAL'
    AttachmentCacheService.new(self).link
  end
end
