
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class CollectionPolicy < ApplicationPolicy
  include SociablePolicy
  include FollowablePolicy
  include TaggablePolicy
  include SubjectablePolicy
  include StageablePolicy

  class Scope < Scope
    def resolve
      if user_exists?
        if user_can_edit?
          scope.all
        else
          scope.includes(:collection_items).where.not(:collection_items => {:collection_id => nil}).where("privacy = ? OR owner_id = ?", 'public', user.id)
        end
      else
        scope.includes(:collection_items).where.not(:collection_items => {:collection_id => nil}).where(privacy: 'public')
      end
    end
  end

  def index?
    record
  end

  def delete_object?
    record if owns?
  end

  def add_object?
    record if owns?
  end

  def create?
    record if owns?
  end

  def show?
    if record.private?
      record if owns?
    else
      record
    end
  end

  def update?
    record if owns?
  end

  def destroy?
    record if owns?
  end

  def add_learning_object?
    record if user_exists?
  end

  def remove_learning_object?
    record if owns?
  end

  def change_privacy?
    record if owns?
  end

  def owner
    record.owner
  end
end
