
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class CollectionSerializer < ActiveModel::Serializer
  cache key: 'collection', expires_in: 4.hours, except: [:likes_count, :liked, :reviewed, :complained, :followed]

  def liked
    object.liked? current_user
  end

  def reviewed
    object.reviewed? current_user
  end

  def complained
    object.complained? current_user
  end

  def followed
    current_user.try(:following?, object)
  end

  def items_thumbnails
    thumbs = []
    i = 0
    while thumbs.size < 6 && i < object.collection_items.size do
      t = object.collection_items[i].thumbnail
      thumbs << t unless t.blank?
      i=i+1
    end
    thumbs
  end

  attributes :id, :name, :curator, :created_at, :updated_at, :description, :privacy, :score, :likes_count, :liked, :followed, :reviewed, :complained, :review_average, :thumbnail, :items_thumbnails

  belongs_to :owner
  has_many :tags
  has_many :subjects
  has_many :educational_stages
  has_many :collection_items
end
