
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

module SearchService
  class Model
    def initialize(search, user)
      raise 'Invalid search' unless search.valid?

      @search = search
      @user = user
    end

    def search
      raise 'Must implement!'
    end

    def autocomplete
      raise 'Must implement!'
    end

    private

    def autocomplete_params
      { limit: 10, misspellings: { below: 5 } }
    end

    def autocomplete_render(result, type, thumbnail)
      result.map do |obj|
        {
          id: obj.id,
          name: obj.name,
          type: type.call(obj),
          thumbnail: thumbnail.call(obj)
        }
      end
    end

    def search_fields
      []
    end

    def mount_query
      match_all_query = {
        query: {
          bool: {
            must: {
              match_all: {}
            },
            filter: mount_filter
          }
        },
        size: @search.results_per_page,
        from: ((@search.page.to_i) * (@search.results_per_page.to_i)).to_s,
        sort: order_hash
      }
      return match_all_query if @search.query == '*'

      {
        query:{
          function_score: {
            query: { bool: {
              must: { dis_max: { queries: mount_queries } },
              filter: mount_filter
            } },
            functions: [{ script_score: { script: { lang: 'painless', file: 'calculate_score' } } }]
          }
        },
        # https://www.elastic.co/guide/en/elasticsearch/guide/current/pagination.html
        # Comeca pagina 0
        size: @search.results_per_page,
        from: ((@search.page.to_i) * (@search.results_per_page.to_i)).to_s,
        sort: order_hash
    }
    end

    def mount_queries
      search_fields.map do |field|
        [
          { match: { "#{field}.word_start" => {
            query: @search.query,
            boost: 10,
            operator: 'and',
            analyzer: 'searchkick_word_search'
          } } },
          { match: { "#{field}.word_start" => {
            query: @search.query,
            boost: 1,
            operator: 'and',
            analyzer: 'searchkick_word_search',
            fuzziness: 1,
            prefix_length: 0,
            max_expansions: 3,
            fuzzy_transpositions: true
          } } }
        ]
      end.flatten
    end

    def mount_filter
      []
    end
  end
end
