
# Copyright (C) 2015 Centro de Computacao Cientifica e Software Livre
# Departamento de Informatica - Universidade Federal do Parana
#
# This file is part of portalmec.
#
# portalmec is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# portalmec is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with portalmec.  If not, see <http://www.gnu.org/licenses/>.

class TagsImporter
  attr_accessor :items

  def import
    tags = {}
    taggings = {}
    @items.each do |learning_object|
      publisher = learning_object.publisher
      categories = parse_categories learning_object.get_metadata_values_of 'dc.subject.category'
      keywords = learning_object.get_metadata_values_of 'dc.subject.keyword'
      (categories + keywords).each do |tag_name|
        if !tag_exists?(tag_name, tags)
          tags[tag_name] = Tag.new(name: tag_name)
          tag = tags[tag_name]
        else
          tag = Tag.find_by_name tag_name
        end

        unless tagging_exists?(tag, publisher, learning_object, taggings)
          taggings [[tag, publisher, learning_object]] = Tagging.new(tag: tag, tagger: publisher, taggable: learning_object)
        end
      end
    end

    Tag.import tags.values
    Tagging.import taggings.values
  end


  private

  def parse_categories(values)
    tags = []
    values.compact.each { |value| tags << value.split(/::|;|\//) }
    tags.flatten.uniq.map(&:strip)
  end

  def tag_exists? (tag_name, tags)
    !Tag.find_by_name(tag_name).nil? || !tags[tag_name].nil?
  end

  def tagging_exists? (tag, tagger, taggable, taggings)
    Tagging.where(tag: tag, tagger: tagger, taggable: taggable).exists? || !taggings[[tag, tagger, taggable]].nil?
  end

end
